==> xl-react-components-0.16.62.tgz: package/tests/e2e/dsl/component/dip/dip-set-of-strings.js <==
import {Action, Expectation} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

const getRow = (cellNumber) => `.testComponent .xl-virtualized-table-row:nth-child(${cellNumber})`;

export const expectAddButtonEnabled = () =>
    Expectation.enabled('.testComponent .xl-react-components-input .add-row-button');

export const expectFilterPresent = () =>
    Expectation.present('.testComponent .search-panel');

export const expectKeyCellValue = (cellNumber, value) =>
    Expectation.attributeContainsValue(`${getRow(cellNumber)} .key-div input`, 'value', value);

export const expectKeyCellPlaceholder = (cellNumber, placeholder) => {
    const selector = `${getRow(cellNumber)} .key-div input`;
    Expectation.attributeContainsValue(selector, 'placeholder', placeholder);
};

export const expectKeyInputFocused = () => {
    const keyInputPlaceholder = 'Add key...';
    browser.driver.sleep(400);
    browser.driver.switchTo().activeElement()
        .getAttribute('placeholder')
        .then((placeholder) => expect(placeholder).toEqual(keyInputPlaceholder)
        );
};

export const clearFilter = () =>
    Action.click('.testComponent .search-panel .xl-react-btn-close');

export const clickOnFilter = () =>
    Action.click('.testComponent .search-panel input[type="text"]');

export const clickOnKeyHeader = () => {
    Action.click('.testComponent .xl-virtualized-table-header-cell:nth-child(1) .sort-icons');
    browser.driver.sleep(400);
};

export const clickAddButton = () => {
    Action.click('.testComponent .xl-react-components-input .add-row-button');
    expectKeyCellValue(1, '');
    expectKeyCellPlaceholder(1, 'Add key...');
};

export const expectDuplicatedKey = (duplicatedKey) => {
    const selector = '.testComponent .xl-react-alert-error.xl-react-alert-message';
    Expectation.textContains(selector, duplicatedKey);
    Expectation.textContains(selector, 'is already in use.');
};

export const removeEntry = (entryNumber) =>
    Action.click(`${getRow(entryNumber)} .xl-react-btn-close`);

export const setKeyValue = (cellNumber, value) => {
    const selector = `${getRow(cellNumber)} .key-div input`;
    Action.typeText(selector, value);
    Action.click('.testComponent .search-panel');
    expectKeyCellValue(cellNumber, value);
};

export const expectAddButtonPresent = () =>
    Expectation.present('.testComponent .xl-react-components-input .add-row-button');

export const expectRemoveEntryNotPresent = (entryNumber) =>
    Expectation.notPresent(`${getRow(entryNumber)} .xl-react-btn-close`);

export const setFilterValue = (value) =>
    Action.typeText('.testComponent .search-panel input[type="text"]', value);

export const expectReadonlyKeyCell = (cellNumber) =>
    Expectation.hasAttribute(`${getRow(cellNumber)} .key-div input`, 'readonly');

const DipSetOfStrings = {
    ...XlComponent,
    clickAddButton,
    clearFilter,
    clickOnFilter,
    clickOnKeyHeader,
    expectAddButtonEnabled,
    expectAddButtonPresent,
    expectDuplicatedKey,
    expectFilterPresent,
    expectKeyCellPlaceholder,
    expectKeyCellValue,
    expectKeyInputFocused,
    expectReadonlyKeyCell,
    expectRemoveEntryNotPresent,
    removeEntry,
    setFilterValue,
    setKeyValue
};

export default DipSetOfStrings;

==> xl-react-components-0.21.12.tgz: package/tests/e2e/dsl/component/dip/dip-set-of-strings.js <==
import {Action, Expectation} from 'protractor-base-dsl';
import XlComponent from '../base/xl-component';

const getRow = (cellNumber) => `.testComponent .xl-virtualized-table-row:nth-child(${cellNumber})`;

export const expectAddButtonEnabled = () =>
    Expectation.enabled('.testComponent .xl-react-components-input .add-row-button');

export const expectFilterPresent = () =>
    Expectation.present('.testComponent .search-panel');

export const expectKeyCellValue = (cellNumber, value) =>
    Expectation.attributeContainsValue(`${getRow(cellNumber)} .key-div input`, 'value', value);

export const expectKeyCellPlaceholder = (cellNumber, placeholder) => {
    const selector = `${getRow(cellNumber)} .key-div input`;
    Expectation.attributeContainsValue(selector, 'placeholder', placeholder);
};

export const expectKeyInputFocused = () => {
    const keyInputPlaceholder = 'Add key...';
    browser.driver.sleep(400);
    browser.driver.switchTo().activeElement()
        .getAttribute('placeholder')
        .then((placeholder) => expect(placeholder).toEqual(keyInputPlaceholder)
        );
};

export const clearFilter = () =>
    Action.click('.testComponent .search-panel .close-icon');

export const clickOnFilter = () =>
    Action.click('.testComponent .search-panel input[type="text"]');

export const clickOnKeyHeader = () => {
    Action.click('.testComponent .xl-virtualized-table-header-cell:nth-child(1) .sort-icons');
    browser.driver.sleep(400);
};

export const clickAddButton = () => {
    Action.click('.testComponent .xl-react-components-input .add-row-button');
    expectKeyCellValue(1, '');
    expectKeyCellPlaceholder(1, 'Add key...');
};

export const expectDuplicatedKey = (duplicatedKey) => {
    const selector = '.testComponent .xl-react-alert-error.xl-react-alert-message';
    Expectation.textContains(selector, duplicatedKey);
    Expectation.textContains(selector, 'is already in use.');
};

export const removeEntry = (entryNumber) =>
    Action.click(`${getRow(entryNumber)} .close-icon`);

export const setKeyValue = (cellNumber, value) => {
    const selector = `${getRow(cellNumber)} .key-div input`;
    Action.typeText(selector, value);
    Action.click('.testComponent .search-panel');
    expectKeyCellValue(cellNumber, value);
};

export const expectAddButtonPresent = () =>
    Expectation.present('.testComponent .xl-react-components-input .add-row-button');

export const expectRemoveEntryNotPresent = (entryNumber) =>
    Expectation.notPresent(`${getRow(entryNumber)} .close-icon`);

export const setFilterValue = (value) =>
    Action.typeNewText('.testComponent .search-panel input[type="text"]', value);

export const expectReadonlyKeyCell = (cellNumber) =>
    Expectation.hasAttribute(`${getRow(cellNumber)} .key-div input`, 'readonly');

const DipSetOfStrings = {
    ...XlComponent,
    clickAddButton,
    clearFilter,
    clickOnFilter,
    clickOnKeyHeader,
    expectAddButtonEnabled,
    expectAddButtonPresent,
    expectDuplicatedKey,
    expectFilterPresent,
    expectKeyCellPlaceholder,
    expectKeyCellValue,
    expectKeyInputFocused,
    expectReadonlyKeyCell,
    expectRemoveEntryNotPresent,
    removeEntry,
    setFilterValue,
    setKeyValue
};

export default DipSetOfStrings;
